You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@wicket.apache.org by jd...@apache.org on 2006/11/06 14:33:26 UTC

svn commit: r471726 [2/4] - in /incubator/wicket/trunk/wicket/src: main/java/wicket/protocol/http/ main/java/wicket/util/diff/ main/java/wicket/util/tester/ test/java/wicket/ test/java/wicket/ajax/ test/java/wicket/ajax/markup/html/ajaxLink/ test/java/...

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/PackageResourceTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/PackageResourceTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/ScopedComponentResolverTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/ScopedComponentResolverTest.java Mon Nov  6 05:33:20 2006
@@ -44,7 +44,7 @@
 	protected void setUp() throws Exception
 	{
 		super.setUp();
-		application.getPageSettings().addComponentResolver(new ScopedComponentResolver());
+		tester.getApplication().getPageSettings().addComponentResolver(new ScopedComponentResolver());
 	}
 
 	/**

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/autolink/MyPageExpectedResult.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/autolink/MyPageExpectedResult.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/autolink/MyPageExpectedResult.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/autolink/MyPageExpectedResult.html Mon Nov  6 05:33:20 2006
@@ -3,13 +3,13 @@
   <body>
     <wicket:link>
       <span><em>My Page</em></span>
-      <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.autolink.PageA">Page A</a>
-      <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.autolink.sub.PageB">Page B</a>
+      <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.autolink.PageA">Page A</a>
+      <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.autolink.sub.PageB">Page B</a>
     </wicket:link>
     START<br>
     <wicket:child><wicket:extend>
   <wicket:link>
-    <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.autolink.PageA">Page A</a>
+    <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.autolink.PageA">Page A</a>
   </wicket:link>
   MyPage
 </wicket:extend></wicket:child>

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/autolink/PageAExpectedResult.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/autolink/PageAExpectedResult.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/autolink/PageAExpectedResult.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/autolink/PageAExpectedResult.html Mon Nov  6 05:33:20 2006
@@ -2,9 +2,9 @@
 <html>
   <body>
     <wicket:link>
-      <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.autolink.MyPage">My Page</a>
+      <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.autolink.MyPage">My Page</a>
       <span><em>Page A</em></span>
-      <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.autolink.sub.PageB">Page B</a>
+      <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.autolink.sub.PageB">Page B</a>
     </wicket:link>
     START<br>
     <wicket:child><wicket:extend>

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/basic/HomePageRedirectTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/basic/HomePageRedirectTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/basic/HomePageRedirectTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/basic/HomePageRedirectTest.java Mon Nov  6 05:33:20 2006
@@ -17,8 +17,8 @@
 package wicket.markup.html.basic;
 
 import junit.framework.TestCase;
-import wicket.protocol.http.MockWebApplication;
 import wicket.util.diff.DiffUtil;
+import wicket.util.tester.WicketTester;
 
 /**
  * @author jcompagner
@@ -40,18 +40,16 @@
 	 */
 	public void testRenderHomePagePageRedirect() throws Exception
 	{
-		MockWebApplication application = new MockWebApplication(null);
-
-		application.setHomePage(HomePagePageRedirect.class);
+		WicketTester tester = new WicketTester(HomePagePageRedirect.class);
 
 		// Do the processing
-		application.setupRequestAndResponse();
-		application.processRequestCycle();
+		tester.setupRequestAndResponse();
+		tester.processRequestCycle();
 
-		assertEquals(RedirectPage.class, application.getLastRenderedPage().getClass());
+		assertEquals(RedirectPage.class, tester.getLastRenderedPage().getClass());
 
 		// Validate the document
-		String document = application.getServletResponse().getDocument();
+		String document = tester.getServletResponse().getDocument();
 		assertTrue(DiffUtil.validatePage(document, this.getClass(), "RedirectPage.html"));
 
 	}
@@ -61,20 +59,16 @@
 	 */
 	public void testRenderHomePageClassRedirect() throws Exception
 	{
-		MockWebApplication application = new MockWebApplication(null);
-
-		application.setHomePage(HomePageClassRedirect.class);
+		WicketTester tester = new WicketTester(HomePageClassRedirect.class);
 
 		// Do the processing
-		application.setupRequestAndResponse();
-		application.processRequestCycle();
+		tester.setupRequestAndResponse();
+		tester.processRequestCycle();
 
-		assertEquals(RedirectPage.class, application.getLastRenderedPage().getClass());
+		assertEquals(RedirectPage.class, tester.getLastRenderedPage().getClass());
 
 		// Validate the document
-		String document = application.getServletResponse().getDocument();
+		String document = tester.getServletResponse().getDocument();
 		assertTrue(DiffUtil.validatePage(document, this.getClass(), "RedirectPage.html"));
-
 	}
-
 }

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/basic/SimplePageExpectedResult_12.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/basic/SimplePageExpectedResult_12.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/basic/SimplePageExpectedResult_12.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/basic/SimplePageExpectedResult_12.html Mon Nov  6 05:33:20 2006
@@ -1,56 +1,56 @@
-<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
-       "http://www.w3.org/TR/html4/strict.dtd">
-<html>
-<head>
-  <title>CSS-basiertes Layout</title>
-  <link href="/WicketTester/basis.css" type="text/css" rel="stylesheet">
-
-  <style type="text/css">@import url(modern_ohne_ie.css) all;</style>
-
-  <wicket:link>
-  <!--[if IE]>
-    <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.basic.SimplePage_3">Link</a>
-  <![endif]-->
-
-  <!--[if IE 6]>
-    <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.basic.SimplePage_3">Link</a>
-  <![endif]-->
-
-  <!--[if gte IE 5.5]>
-    <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.basic.SimplePage_3">Link</a>
-  <![endif]-->
-
-  <!--[if lte IE 5.5999]>
-    <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.basic.SimplePage_3">Link</a>
-  <![endif]-->
-
-  <!--[if lt IE 5.1]>
-    <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.basic.SimplePage_3" wicket:id="link">Link</a>
-  <![endif]-->
-  
-  <!--[if IE]>
-    <style type="text/css">@import url(ie.css);</style>
-  <![endif]-->
-
-  <!--[if IE 6]>
-    <style type="text/css">@import url(ie.css);</style>
-  <![endif]-->
-
-  <!--[if gte IE 5.5]>
-    <style type="text/css">@import url(ie.css);</style>
-  <![endif]-->
-
-  <!--[if lte IE 5.5999]>
-    <style type="text/css">@import url(ie.css);</style>
-  <![endif]-->
-
-  <!--[if lt IE 5.1]>
-    <style type="text/css">@import url(ie.css);</style>
-  <![endif]-->
-  </wicket:link>
-
-</head>
-<body>
-  <!-- HTML-Quelltext -->
-</body>
-</html>
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
+       "http://www.w3.org/TR/html4/strict.dtd">
+<html>
+<head>
+  <title>CSS-basiertes Layout</title>
+  <link href="/DummyApplication/basis.css" type="text/css" rel="stylesheet">
+
+  <style type="text/css">@import url(modern_ohne_ie.css) all;</style>
+
+  <wicket:link>
+  <!--[if IE]>
+    <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.basic.SimplePage_3">Link</a>
+  <![endif]-->
+
+  <!--[if IE 6]>
+    <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.basic.SimplePage_3">Link</a>
+  <![endif]-->
+
+  <!--[if gte IE 5.5]>
+    <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.basic.SimplePage_3">Link</a>
+  <![endif]-->
+
+  <!--[if lte IE 5.5999]>
+    <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.basic.SimplePage_3">Link</a>
+  <![endif]-->
+
+  <!--[if lt IE 5.1]>
+    <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.basic.SimplePage_3" wicket:id="link">Link</a>
+  <![endif]-->
+  
+  <!--[if IE]>
+    <style type="text/css">@import url(ie.css);</style>
+  <![endif]-->
+
+  <!--[if IE 6]>
+    <style type="text/css">@import url(ie.css);</style>
+  <![endif]-->
+
+  <!--[if gte IE 5.5]>
+    <style type="text/css">@import url(ie.css);</style>
+  <![endif]-->
+
+  <!--[if lte IE 5.5999]>
+    <style type="text/css">@import url(ie.css);</style>
+  <![endif]-->
+
+  <!--[if lt IE 5.1]>
+    <style type="text/css">@import url(ie.css);</style>
+  <![endif]-->
+  </wicket:link>
+
+</head>
+<body>
+  <!-- HTML-Quelltext -->
+</body>
+</html>

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/basic/SimplePageTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/basic/SimplePageTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/basic/SimpleResponsePageClassTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/basic/SimpleResponsePageClassTest.java Mon Nov  6 05:33:20 2006
@@ -6,7 +6,7 @@
 import junit.framework.TestCase;
 import wicket.markup.html.form.Form;
 import wicket.protocol.http.MockHttpServletRequest;
-import wicket.protocol.http.MockWebApplication;
+import wicket.util.tester.WicketTester;
 
 /**
  * @author jcompagner
@@ -19,23 +19,19 @@
 	 */
 	public void testResponsePageClass() throws Exception
 	{
-		MockWebApplication mockWebApp = new MockWebApplication(null);
-
-		mockWebApp.setHomePage(SimpleResponsePageClass.class);
-		mockWebApp.setupRequestAndResponse();
-		mockWebApp.processRequestCycle();
-		SimpleResponsePageClass manageBook = (SimpleResponsePageClass)mockWebApp
-				.getLastRenderedPage();
+		WicketTester tester = new WicketTester(SimpleResponsePageClass.class);
+		tester.setupRequestAndResponse();
+		tester.processRequestCycle();
+		SimpleResponsePageClass manageBook = (SimpleResponsePageClass)tester.getLastRenderedPage();
 
 		Form form = (Form)manageBook.get("form");
-		mockWebApp.setupRequestAndResponse();
+		tester.setupRequestAndResponse();
 
-		MockHttpServletRequest mockRequest = mockWebApp.getServletRequest();
+		MockHttpServletRequest mockRequest = tester.getServletRequest();
 		mockRequest.setRequestToComponent(form);
-		mockWebApp.processRequestCycle();
+		tester.processRequestCycle();
 
 		// assertion failed, getLastRenderedPage() return null.
-		assertTrue(mockWebApp.getLastRenderedPage() instanceof SimplePage);
-
+		assertTrue(tester.getLastRenderedPage() instanceof SimplePage);
 	}
 }

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTest.java Mon Nov  6 05:33:20 2006
@@ -75,21 +75,21 @@
 	{
 		executeTest(BoxBorderTestPage_3.class, "BoxBorderTestPage_ExpectedResult_3.html");
 
-		application.getLastRenderedPage().get("border");
-		Form form = (Form)application.getLastRenderedPage().get("border:myForm");
+		tester.getLastRenderedPage().get("border");
+		Form form = (Form)tester.getLastRenderedPage().get("border:myForm");
 
-		TextField input = (TextField)application.getLastRenderedPage().get("border:myForm:borderBody:name");
+		TextField input = (TextField)tester.getLastRenderedPage().get("border:myForm:borderBody:name");
 		assertEquals("", input.getModelObjectAsString());
 
-		application.setupRequestAndResponse();
+		tester.setupRequestAndResponse();
 
-		MockHttpServletRequest mockRequest = application.getServletRequest();
+		MockHttpServletRequest mockRequest = tester.getServletRequest();
 		mockRequest.setRequestToComponent(form);
 		mockRequest.setParameter(input.getInputName(), "jdo");
 
-		application.processRequestCycle();
+		tester.processRequestCycle();
 
-		input = (TextField)application.getLastRenderedPage().get("border:myForm:borderBody:name");
+		input = (TextField)tester.getLastRenderedPage().get("border:myForm:borderBody:name");
 		assertEquals("jdo", input.getModelObjectAsString());
 	}
 
@@ -102,13 +102,11 @@
 		Class<? extends Page> pageClass = BorderTestHierarchyPage_4.class;
 
 		System.out.println("=== " + pageClass.getName() + " ===");
-		application.setHomePage(pageClass);
-		application.setupRequestAndResponse();
-
+		
 		WicketRuntimeException wicketRuntimeException = null;
 		try
 		{
-			application.processRequestCycle();
+			tester.startPage(pageClass);
 		}
 		catch (WicketRuntimeException e)
 		{
@@ -159,9 +157,9 @@
 	{
 		executeTest(BoxBorderTestPage_7.class, "BoxBorderTestPage_ExpectedResult_7.html");
 		
-		application.clickLink("link");
+		tester.clickLink("link");
 
-		String document = application.getServletResponse().getDocument();
+		String document = tester.getServletResponse().getDocument();
 		assertTrue(DiffUtil.validatePage(document, this.getClass(), "BoxBorderTestPage_ExpectedResult_7-1.html"));
 	}
 }

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_ExpectedResult_2.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_ExpectedResult_2.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_ExpectedResult_2.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_ExpectedResult_2.html Mon Nov  6 05:33:20 2006
@@ -10,7 +10,7 @@
                             <td width = "100%">
                                 <wicket:body>
      this is inside box: <input value="" type="text" name="box:boxBody:text" wicket:id="text"/><br/>
-     <img src="/WicketTester/WicketTester/resources/wicket.markup.html.border.BoxBorderTestPage_2/test.png" wicket:id="img"/>
+     <img src="/DummyApplication/DummyApplication/resources/wicket.markup.html.border.BoxBorderTestPage_2/test.png" wicket:id="img"/>
   </wicket:body>
                             </td>
                         </tr>

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_ExpectedResult_3.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_ExpectedResult_3.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_ExpectedResult_3.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_ExpectedResult_3.html Mon Nov  6 05:33:20 2006
@@ -2,7 +2,7 @@
 <html xmlns="http://www.w3.org/1999/xhtml">
 <body>
   <span wicket:id="border"><wicket:border>
-  <form action="/WicketTester/WicketTester?wicket:interface=:0:border:myForm::IFormSubmitListener" id="border_myForm" method="post" wicket:id="myForm">
+  <form action="/DummyApplication/DummyApplication?wicket:interface=:0:border:myForm::IFormSubmitListener" id="border_myForm" method="post" wicket:id="myForm">
 <div style="display:none"><input type="hidden" name="border_myForm:hf:fs" id="border_myForm:hf:fs"/>
 <input type="hidden" name="wicketState" id="border_myForm:hf:ws"/></div>
 	<wicket:body>

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_ExpectedResult_7-1.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_ExpectedResult_7-1.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_ExpectedResult_7-1.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_ExpectedResult_7-1.html Mon Nov  6 05:33:20 2006
@@ -1,15 +1,15 @@
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
-<body>
-  <span wicket:id="border"><wicket:border>
-  <form action="/WicketTester/WicketTester?wicket:interface=:0:border:myForm::IFormSubmitListener" id="border_myForm" method="post" wicket:id="myForm">
-<div style="display:none"><input type="hidden" name="border_myForm:hf:fs" id="border_myForm:hf:fs"/>
-<input type="hidden" name="wicketState" id="border_myForm:hf:ws"/></div>
-	<wicket:body>
-    
-  </wicket:body>
-  </form>
-</wicket:border></span>
-  <a href="/WicketTester/WicketTester?wicket:interface=:0:link::ILinkListener" wicket:id="link">link</a>
-</body>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml">
+<body>
+  <span wicket:id="border"><wicket:border>
+  <form action="/DummyApplication/DummyApplication?wicket:interface=:0:border:myForm::IFormSubmitListener" id="border_myForm" method="post" wicket:id="myForm">
+<div style="display:none"><input type="hidden" name="border_myForm:hf:fs" id="border_myForm:hf:fs"/>
+<input type="hidden" name="wicketState" id="border_myForm:hf:ws"/></div>
+	<wicket:body>
+    
+  </wicket:body>
+  </form>
+</wicket:border></span>
+  <a href="/DummyApplication/DummyApplication?wicket:interface=:0:link::ILinkListener" wicket:id="link">link</a>
+</body>
 </html>

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_ExpectedResult_7.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_ExpectedResult_7.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_ExpectedResult_7.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/border/BoxBorderTestPage_ExpectedResult_7.html Mon Nov  6 05:33:20 2006
@@ -1,15 +1,15 @@
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
-<body>
-  <span wicket:id="border"><wicket:border>
-  <form action="/WicketTester/WicketTester?wicket:interface=:0:border:myForm::IFormSubmitListener" id="border_myForm" method="post" wicket:id="myForm">
-<div style="display:none"><input type="hidden" name="border_myForm:hf:fs" id="border_myForm:hf:fs"/>
-<input type="hidden" name="wicketState" id="border_myForm:hf:ws"/></div>
-	<wicket:body>
-    
-  </wicket:body>
-  </form>
-</wicket:border></span>
-  <a href="/WicketTester/WicketTester?wicket:interface=:0:link::ILinkListener" wicket:id="link">link</a>
-</body>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml">
+<body>
+  <span wicket:id="border"><wicket:border>
+  <form action="/DummyApplication/DummyApplication?wicket:interface=:0:border:myForm::IFormSubmitListener" id="border_myForm" method="post" wicket:id="myForm">
+<div style="display:none"><input type="hidden" name="border_myForm:hf:fs" id="border_myForm:hf:fs"/>
+<input type="hidden" name="wicketState" id="border_myForm:hf:ws"/></div>
+	<wicket:body>
+    
+  </wicket:body>
+  </form>
+</wicket:border></span>
+  <a href="/DummyApplication/DummyApplication?wicket:interface=:0:link::ILinkListener" wicket:id="link">link</a>
+</body>
 </html>

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/ButtonTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/ButtonTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/ButtonTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/ButtonTest.java Mon Nov  6 05:33:20 2006
@@ -43,7 +43,7 @@
 	 */
 	public void testRender()
 	{
-		application.startPage(new ITestPageSource()
+		tester.startPage(new ITestPageSource()
 		{
 			private static final long serialVersionUID = 1L;
 
@@ -66,7 +66,7 @@
 			
 		});
 	
-		application.assertComponent(MockPageWithOneComponent.COMPONENT_ID, Button.class);
+		tester.assertComponent(MockPageWithOneComponent.COMPONENT_ID, Button.class);
 	}
 	
 	/**
@@ -75,10 +75,10 @@
 	 */
 	public void testRender_2()
 	{
-		application.startPage(MockFormAndButtonPage.class);
+		tester.startPage(MockFormAndButtonPage.class);
 
-		application.assertContains("<input name=\"button\" type=\"submit\" wicket:id=\"button\"/>");
-		String doc = application.getServletResponse().getDocument();
+		tester.assertContains("<input name=\"button\" type=\"submit\" wicket:id=\"button\"/>");
+		String doc = tester.getServletResponse().getDocument();
 		boolean contains = doc.contains("<input onclick=\"var e=document.getElementById('form:hf:fs'); e.name='button2'; e.value='x';var f=document.getElementById('form');var ff=f;if (ff.onsubmit != undefined) { if (ff.onsubmit()==false) return false; }f.submit();e.value='';e.name='';return false;\" type=\"submit\" name=\"button2\" wicket:id=\"button2\"/>");		
 		assertTrue(contains);
 	}

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupDisabledTestPage_expected.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupDisabledTestPage_expected.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupDisabledTestPage_expected.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupDisabledTestPage_expected.html Mon Nov  6 05:33:20 2006
@@ -2,7 +2,7 @@
 <head><title>CheckGroupTestPage1</title></head>
 <body>
     <!--  In addition test that chars are not converted from upper to lower and vice versa -->
-	<FORM action="/WicketTester/WicketTester?wicket:interface=:0:form::IFormSubmitListener" id="form" method="post" wicket:id="form">
+	<FORM action="/DummyApplication/DummyApplication?wicket:interface=:0:form::IFormSubmitListener" id="form" method="post" wicket:id="form">
 <div style="display:none"><input type="hidden" name="form:hf:fs" id="form:hf:fs"/>
 <input type="hidden" name="wicketState" id="form:hf:ws"/></div>
 		<span name="group" disabled="disabled" wicket:id="group">

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTest.java Mon Nov  6 05:33:20 2006
@@ -126,7 +126,7 @@
 		assertTrue(group3.getModelObject() == list);
 
 		// set up necessary objects to emulate a form submission
-		application.createRequestCycle();
+		tester.createRequestCycle();
 
 		new Check<String>(container, "check1", new Model<String>(check1));
 		new Check(group, "prop2");
@@ -141,19 +141,19 @@
 		assertTrue("running with nothing selected - model must be empty", modelObject.getProp1()
 				.size() == 0);
 
-		application.getServletRequest().setParameter(group.getInputName(), "container:check1");
+		tester.getServletRequest().setParameter(group.getInputName(), "container:check1");
 		form.onFormSubmitted();
 		assertTrue("running with choice1 selected - model must only contain value of check1",
 				modelObject.getProp1().size() == 1 && modelObject.getProp1().contains(check1));
 
-		application.getServletRequest().setParameter(group.getInputName(), "prop2");
+		tester.getServletRequest().setParameter(group.getInputName(), "prop2");
 		form.onFormSubmitted();
 		assertTrue("running with choice2 selected - model must only contain value of check2",
 				modelObject.getProp1().size() == 1 && modelObject.getProp1().contains(check2));
 
 		// throw in some nulls into the request param to make sure they are
 		// ignored
-		application.getServletRequest().getParameterMap().put(group.getInputName(),
+		tester.getServletRequest().getParameterMap().put(group.getInputName(),
 				new String[] { null, "container:check1", null, "prop2" });
 		form.onFormSubmitted();
 		assertTrue(
@@ -161,7 +161,7 @@
 				modelObject.getProp1().size() == 2 && modelObject.getProp1().contains(check2)
 						&& modelObject.getProp1().contains(check1));
 
-		application.getServletRequest().getParameterMap().put(group.getInputName(),
+		tester.getServletRequest().getParameterMap().put(group.getInputName(),
 				new String[] { "some weird path to test error" });
 		try
 		{

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage1_expected.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage1_expected.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage1_expected.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage1_expected.html Mon Nov  6 05:33:20 2006
@@ -2,7 +2,7 @@
 <head><title>CheckGroupTestPage1</title></head>
 <body>
     <!--  In addition test that chars are not converted from upper to lower and vice versa -->
-	<FORM action="/WicketTester/WicketTester?wicket:interface=:0:form::IFormSubmitListener" id="form" method="post" wicket:id="form">
+	<FORM action="/DummyApplication/DummyApplication?wicket:interface=:0:form::IFormSubmitListener" id="form" method="post" wicket:id="form">
 <div style="display:none"><input type="hidden" name="form:hf:fs" id="form:hf:fs"/>
 <input type="hidden" name="wicketState" id="form:hf:ws"/></div>
 		

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage2_expected.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage2_expected.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage2_expected.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage2_expected.html Mon Nov  6 05:33:20 2006
@@ -1,7 +1,7 @@
 <html>
 <head><title>CheckGroupTestPage2</title></head>
 <body>
-	<form action="/WicketTester/WicketTester?wicket:interface=:1:form::IFormSubmitListener" id="form" method="post" wicket:id="form">
+	<form action="/DummyApplication/DummyApplication?wicket:interface=:1:form::IFormSubmitListener" id="form" method="post" wicket:id="form">
 <div style="display:none"><input type="hidden" name="form:hf:fs" id="form:hf:fs"/>
 <input type="hidden" name="wicketState" id="form:hf:ws"/></div>
 		

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage3_expected.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage3_expected.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage3_expected.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage3_expected.html Mon Nov  6 05:33:20 2006
@@ -1,7 +1,7 @@
 <html>
 <head><title>CheckGroupTestPage3</title></head>
 <body>
-	<form action="/WicketTester/WicketTester?wicket:interface=:2:form::IFormSubmitListener" id="form" method="post" wicket:id="form">
+	<form action="/DummyApplication/DummyApplication?wicket:interface=:2:form::IFormSubmitListener" id="form" method="post" wicket:id="form">
 <div style="display:none"><input type="hidden" name="form:hf:fs" id="form:hf:fs"/>
 <input type="hidden" name="wicketState" id="form:hf:ws"/></div>
 		

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage4_expected.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage4_expected.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage4_expected.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/CheckGroupTestPage4_expected.html Mon Nov  6 05:33:20 2006
@@ -1,7 +1,7 @@
 <html>
 <head><title>CheckGroupTestPage4</title></head>
 <body>
-	<form action="/WicketTester/WicketTester?wicket:interface=:3:form::IFormSubmitListener" id="form" method="post" wicket:id="form">
+	<form action="/DummyApplication/DummyApplication?wicket:interface=:3:form::IFormSubmitListener" id="form" method="post" wicket:id="form">
 <div style="display:none"><input type="hidden" name="form:hf:fs" id="form:hf:fs"/>
 <input type="hidden" name="wicketState" id="form:hf:ws"/></div>
 		

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/RadioGroupDisabledTestPage_expected.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/RadioGroupDisabledTestPage_expected.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/RadioGroupDisabledTestPage_expected.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/RadioGroupDisabledTestPage_expected.html Mon Nov  6 05:33:20 2006
@@ -1,7 +1,7 @@
 <html>
 <head><title>RadioGroupTestPage1</title></head>
 <body>
-	<form action="/WicketTester/WicketTester?wicket:interface=:0:form::IFormSubmitListener" id="form" method="post" wicket:id="form">
+	<form action="/DummyApplication/DummyApplication?wicket:interface=:0:form::IFormSubmitListener" id="form" method="post" wicket:id="form">
 <div style="display:none"><input type="hidden" name="form:hf:fs" id="form:hf:fs"/>
 <input type="hidden" name="wicketState" id="form:hf:ws"/></div>
 		<span name="group" disabled="disabled" wicket:id="group">

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/RadioGroupTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/RadioGroupTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/RadioGroupTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/RadioGroupTest.java Mon Nov  6 05:33:20 2006
@@ -102,7 +102,7 @@
 
 		// set up necessary objects to emulate a form submission
 
-		application.createRequestCycle();
+		tester.createRequestCycle();
 		MockPage page = new MockPage();
 
 		// create component hierarchy
@@ -138,8 +138,8 @@
 		assertTrue("group2: running with nothing selected - model must be set to null", model
 				.getObject(null) == null);
 
-		application.getServletRequest().setParameter(group.getInputName(), choice1.getPath().substring(group.getPath().length() + 1));
-		application.getServletRequest().setParameter(group2.getInputName(), choice3.getPath().substring(group2.getPath().length() + 1));
+		tester.getServletRequest().setParameter(group.getInputName(), choice1.getPath().substring(group.getPath().length() + 1));
+		tester.getServletRequest().setParameter(group2.getInputName(), choice3.getPath().substring(group2.getPath().length() + 1));
 		form.onFormSubmitted();
 		assertEquals("group: running with choice1 selected - model must be set to value of radio1",
 				modelObject.getProp1(), choice1.getModelObject());
@@ -147,12 +147,12 @@
 				"group2: running with choice3 selected - model must be set to value of radio1",
 				model.getObject(null), choice3.getModelObject());
 
-		application.getServletRequest().setParameter(group.getInputName(), choice2.getPath().substring(group.getPath().length() + 1));
+		tester.getServletRequest().setParameter(group.getInputName(), choice2.getPath().substring(group.getPath().length() + 1));
 		form.onFormSubmitted();
 		assertEquals("group: running with choice2 selected - model must be set to value of radio2",
 				modelObject.getProp1(), choice2.getModelObject());
 
-		application.getServletRequest().setParameter(group2.getInputName(), choice1.getPath().substring(group.getPath().length() + 1));
+		tester.getServletRequest().setParameter(group2.getInputName(), choice1.getPath().substring(group.getPath().length() + 1));
 		try
 		{
 			form.onFormSubmitted();

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/RadioGroupTestPage1_expected.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/RadioGroupTestPage1_expected.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/RadioGroupTestPage1_expected.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/RadioGroupTestPage1_expected.html Mon Nov  6 05:33:20 2006
@@ -1,7 +1,7 @@
 <html>
 <head><title>RadioGroupTestPage1</title></head>
 <body>
-	<form action="/WicketTester/WicketTester?wicket:interface=:0:form::IFormSubmitListener" id="form" method="post" wicket:id="form">
+	<form action="/DummyApplication/DummyApplication?wicket:interface=:0:form::IFormSubmitListener" id="form" method="post" wicket:id="form">
 <div style="display:none"><input type="hidden" name="form:hf:fs" id="form:hf:fs"/>
 <input type="hidden" name="wicketState" id="form:hf:ws"/></div>
 		

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/RadioGroupTestPage3_expected.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/RadioGroupTestPage3_expected.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/RadioGroupTestPage3_expected.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/RadioGroupTestPage3_expected.html Mon Nov  6 05:33:20 2006
@@ -1,6 +1,6 @@
 <html>
 <body>
-<form action="/WicketTester/WicketTester?wicket:interface=:0:form::IFormSubmitListener" id="form" method="post" wicket:id="form">
+<form action="/DummyApplication/DummyApplication?wicket:interface=:0:form::IFormSubmitListener" id="form" method="post" wicket:id="form">
 <div style="display:none"><input type="hidden" name="form:hf:fs" id="form:hf:fs"/>
 <input type="hidden" name="wicketState" id="form:hf:ws"/></div>
 	

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/ValidatorPropertiesTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/ValidatorPropertiesTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/ValidatorPropertiesTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/ValidatorPropertiesTest.java Mon Nov  6 05:33:20 2006
@@ -34,7 +34,7 @@
 	 */
 	public void test1()
 	{
-		WicketTester tester = new MyTesterApplication();
+		WicketTester tester = new WicketTester(new MyTesterApplication());
 		tester.setupRequestAndResponse();
 		tester.createRequestCycle();
 
@@ -104,12 +104,13 @@
 	 */
 	public void test2()
 	{
-		WicketTester tester = new MyTesterApplication();
-		tester.getResourceSettings().setThrowExceptionOnMissingResource(false);
+		WicketTester tester = new WicketTester(new MyTesterApplication());
+		tester.getApplication().getResourceSettings().setThrowExceptionOnMissingResource(false);
 		tester.setupRequestAndResponse();
 		tester.createRequestCycle();
 
-		String str = tester.getResourceSettings().getLocalizer().getString("XXX", null);
+		String str = tester.getApplication().getResourceSettings().getLocalizer().getString("XXX",
+				null);
 		assertEquals("[Warning: String resource for 'XXX' not found]", str);
 	}
 
@@ -118,15 +119,15 @@
 	 */
 	public void test3()
 	{
-		WicketTester tester = new MyTesterApplication();
-		tester.getResourceSettings().setThrowExceptionOnMissingResource(true);
+		WicketTester tester = new WicketTester(new MyTesterApplication());
+		tester.getApplication().getResourceSettings().setThrowExceptionOnMissingResource(true);
 		tester.setupRequestAndResponse();
 		tester.createRequestCycle();
 
 		boolean hit = false;
 		try
 		{
-			tester.getResourceSettings().getLocalizer().getString("XXX", null);
+			tester.getApplication().getResourceSettings().getLocalizer().getString("XXX", null);
 		}
 		catch (MissingResourceException ex)
 		{

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/login/InterceptTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/login/InterceptTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/login/InterceptTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/login/InterceptTest.java Mon Nov  6 05:33:20 2006
@@ -11,25 +11,28 @@
 import junit.framework.TestCase;
 import wicket.Component;
 import wicket.ISessionFactory;
+import wicket.Page;
 import wicket.RestartResponseAtInterceptPageException;
 import wicket.Session;
 import wicket.authorization.Action;
 import wicket.authorization.IAuthorizationStrategy;
-import wicket.protocol.http.MockWebApplication;
 import wicket.protocol.http.WebApplication;
 import wicket.protocol.http.WebRequestCycle;
 import wicket.protocol.http.WebSession;
 import wicket.util.string.Strings;
+import wicket.util.tester.WicketTester;
 
 
 /**
- * @author marrink
  * 
+ * @author marrink
  */
 public class InterceptTest extends TestCase
 {
-	private MyMockWebApplication application;
+	private WicketTester tester;
 
+	private MyWebApplication application;
+	
 	/**
 	 * Constructor for InterceptTest.
 	 * 
@@ -47,18 +50,10 @@
 	protected void setUp() throws Exception
 	{
 		super.setUp();
-		application = new MyMockWebApplication("src/test/"
+		
+		application = new MyWebApplication();
+		tester = new WicketTester(application, "src/test/"
 				+ getClass().getPackage().getName().replace('.', '/'));
-		application.setHomePage(MockHomePage.class);
-	}
-
-	/**
-	 * @see TestCase#tearDown()
-	 */
-	@Override
-	protected void tearDown() throws Exception
-	{
-		super.tearDown();
 	}
 
 	/**
@@ -66,26 +61,26 @@
 	 */
 	public void testClickLink()
 	{
-		application.setupRequestAndResponse();
-		application.processRequestCycle();
-		MockLoginPage loginPage = (MockLoginPage)application.getLastRenderedPage();
+		tester.setupRequestAndResponse();
+		tester.processRequestCycle();
+		MockLoginPage loginPage = (MockLoginPage)tester.getLastRenderedPage();
 		assertEquals(application.getLoginPage(), loginPage.getClass());
 
-		application.setupRequestAndResponse();
-		application.getServletRequest().setRequestToComponent(loginPage.getForm());
-		application.getServletRequest().setParameter(loginPage.getTextField().getInputName(),
+		tester.setupRequestAndResponse();
+		tester.getServletRequest().setRequestToComponent(loginPage.getForm());
+		tester.getServletRequest().setParameter(loginPage.getTextField().getInputName(),
 				"admin");
-		application.processRequestCycle();
+		tester.processRequestCycle();
 
 		// continueToInterceptPage seems to return the same call, causing it to
 		// login twice as a result the lastrendered page is null
-		assertEquals(application.getHomePage(), application.getLastRenderedPage().getClass());
+		assertEquals(application.getHomePage(), tester.getLastRenderedPage().getClass());
 
-		application.setupRequestAndResponse();
-		application.getServletRequest().setRequestToComponent(
-				application.getLastRenderedPage().get("link"));
-		application.processRequestCycle();
-		assertEquals(PageA.class, application.getLastRenderedPage().getClass());
+		tester.setupRequestAndResponse();
+		tester.getServletRequest().setRequestToComponent(
+				tester.getLastRenderedPage().get("link"));
+		tester.processRequestCycle();
+		assertEquals(PageA.class, tester.getLastRenderedPage().getClass());
 	}
 
 	/**
@@ -94,42 +89,56 @@
 	public void testClickLink2()
 	{
 		// same as above but uses different technique to login
-		application.setupRequestAndResponse();
-		application.processRequestCycle();
-		MockLoginPage loginPage = (MockLoginPage)application.getLastRenderedPage();
+		tester.setupRequestAndResponse();
+		tester.processRequestCycle();
+		MockLoginPage loginPage = (MockLoginPage)tester.getLastRenderedPage();
 		assertEquals(application.getLoginPage(), loginPage.getClass());
 
 		// bypass form completely to login but continue to intercept page
-		application.setupRequestAndResponse();
-		WebRequestCycle requestCycle = application.createRequestCycle();
-		assertTrue(((MockLoginPage)application.getLastRenderedPage()).login("admin"));
-		application.processRequestCycle(requestCycle);
-		assertEquals(application.getHomePage(), application.getLastRenderedPage().getClass());
-
-		application.setupRequestAndResponse();
-		application.getServletRequest().setRequestToComponent(
-				application.getLastRenderedPage().get("link"));
-		application.processRequestCycle();
-		assertEquals(PageA.class, application.getLastRenderedPage().getClass());
+		tester.setupRequestAndResponse();
+		WebRequestCycle requestCycle = tester.createRequestCycle();
+		assertTrue(((MockLoginPage)tester.getLastRenderedPage()).login("admin"));
+		tester.processRequestCycle(requestCycle);
+		assertEquals(application.getHomePage(), tester.getLastRenderedPage().getClass());
+
+		tester.setupRequestAndResponse();
+		tester.getServletRequest().setRequestToComponent(
+				tester.getLastRenderedPage().get("link"));
+		tester.processRequestCycle();
+		assertEquals(PageA.class, tester.getLastRenderedPage().getClass());
 	}
 
 	/**
 	 * 
-	 * @author
 	 */
-	private static class MyMockWebApplication extends MockWebApplication implements ISessionFactory
+	private static class MyWebApplication extends WebApplication implements ISessionFactory
 	{
 		private static final long serialVersionUID = 1L;
 
 		/**
 		 * @param path
 		 */
-		public MyMockWebApplication(String path)
+		public MyWebApplication()
 		{
-			super(path);
-			getSecuritySettings().setAuthorizationStrategy(new MyAuthorizationStrategy());
 		}
 
+		/**
+		 * @see wicket.Application#getHomePage()
+		 */
+		@Override
+		public Class<? extends Page> getHomePage()
+		{
+			return MockHomePage.class;
+		}
+
+		@Override
+		protected void init()
+		{
+			super.init();
+			
+			getSecuritySettings().setAuthorizationStrategy(new MyAuthorizationStrategy());
+		}
+		
 		/**
 		 * 
 		 * @return Class

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/persistence/CookieValuePersisterTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/persistence/CookieValuePersisterTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/upload/FileUploadFieldTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/upload/FileUploadFieldTest.java Mon Nov  6 05:33:20 2006
@@ -57,7 +57,7 @@
 		
 		FileUploadField field = new FileUploadField(page.getForm(), "upload");
 
-		application.startPage(new ITestPageSource() 
+		tester.startPage(new ITestPageSource() 
 		{
 			private static final long serialVersionUID = 1L;
 
@@ -68,8 +68,8 @@
 		});
 
 		// Setup the request. It should be a IMultipartWebRequest
-		RequestCycle requestCycle = application.createRequestCycle();
-		MockHttpServletRequest servletRequest = application.getServletRequest();
+		RequestCycle requestCycle = tester.createRequestCycle();
+		MockHttpServletRequest servletRequest = tester.getServletRequest();
 		servletRequest.setMethod("POST");
 		servletRequest.setParameter("form2:hf:fs", "");
 		servletRequest.setParameter("wicketState", "");

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/header/inheritance/InheritanceHeadTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/header/inheritance/InheritanceHeadTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/header/inheritance/InheritanceHeadTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/header/inheritance/InheritanceHeadTest.java Mon Nov  6 05:33:20 2006
@@ -20,7 +20,9 @@
 import wicket.Session;
 import wicket.WicketTestCase;
 import wicket.markup.MarkupException;
+import wicket.protocol.http.WebApplication;
 import wicket.protocol.http.WebSession;
+import wicket.resource.DummyApplication;
 import wicket.util.tester.WicketTester;
 
 /**
@@ -73,7 +75,7 @@
 	 */
 	public void test_3() throws Exception
 	{
-		application = new WicketTester()
+		WebApplication app = new DummyApplication()
 		{
 			/**
 			 * @see wicket.protocol.http.WebApplication#newSession()
@@ -84,6 +86,8 @@
 				return new WebSession(this).setStyle("myStyle");
 			}
 		};
+		
+		tester = new WicketTester(app);
 
 		executeTest(ConcretePage2.class, "ExpectedResult3.html");
 	}

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/header/testing3/HeaderTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/header/testing3/HeaderTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/header/testing3/HeaderTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/header/testing3/HeaderTest.java Mon Nov  6 05:33:20 2006
@@ -43,7 +43,7 @@
 	public void test_1() throws Exception
 	{
 		executeTest(TestPage.class, "TestPage_ExpectedResult-1.html");
-		TestPage page = (TestPage)application.getLastRenderedPage();
+		TestPage page = (TestPage)tester.getLastRenderedPage();
 
 		executedListener(TestPage.class, page.get("link"), "TestPage_ExpectedResult-2.html");
 	}

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/header/testing3/TestPage_ExpectedResult-1.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/header/testing3/TestPage_ExpectedResult-1.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/header/testing3/TestPage_ExpectedResult-1.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/header/testing3/TestPage_ExpectedResult-1.html Mon Nov  6 05:33:20 2006
@@ -1,13 +1,13 @@
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
-<head>
-  <title>test page</title>
-
-</head>
-<body onload="function_1()">
-  <span wicket:id="panel"><wicket:panel>
-    Panel 1
-  </wicket:panel></span>
-  <a href="/WicketTester/WicketTester?wicket:interface=:0:link::ILinkListener" wicket:id="link">Replace the panel</a>
-</body>
-</html>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml">
+<head>
+  <title>test page</title>
+
+</head>
+<body onload="function_1()">
+  <span wicket:id="panel"><wicket:panel>
+    Panel 1
+  </wicket:panel></span>
+  <a href="/DummyApplication/DummyApplication?wicket:interface=:0:link::ILinkListener" wicket:id="link">Replace the panel</a>
+</body>
+</html>

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/header/testing3/TestPage_ExpectedResult-2.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/header/testing3/TestPage_ExpectedResult-2.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/header/testing3/TestPage_ExpectedResult-2.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/header/testing3/TestPage_ExpectedResult-2.html Mon Nov  6 05:33:20 2006
@@ -1,12 +1,12 @@
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
-<head>
-  <title>test page</title>
-</head>
-<body>
-  <span wicket:id="panel"><wicket:panel>
-  Panel 2
-</wicket:panel></span>
-  <a href="/WicketTester/WicketTester?wicket:interface=:0:link:1:ILinkListener" wicket:id="link">Replace the panel</a>
-</body>
-</html>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml">
+<head>
+  <title>test page</title>
+</head>
+<body>
+  <span wicket:id="panel"><wicket:panel>
+  Panel 2
+</wicket:panel></span>
+  <a href="/DummyApplication/DummyApplication?wicket:interface=:0:link:1:ILinkListener" wicket:id="link">Replace the panel</a>
+</body>
+</html>

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/internal/EnclosureTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/internal/EnclosureTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/internal/EnclosureTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/internal/EnclosureTest.java Mon Nov  6 05:33:20 2006
@@ -24,6 +24,8 @@
 import wicket.markup.MarkupResourceStream;
 import wicket.markup.parser.filter.EnclosureHandler;
 import wicket.markup.resolver.EnclosureResolver;
+import wicket.protocol.http.WebApplication;
+import wicket.resource.DummyApplication;
 import wicket.util.tester.WicketTester;
 
 /**
@@ -49,7 +51,7 @@
 	@Override
 	protected void setUp() throws Exception
 	{
-		application = new WicketTester(null)
+		WebApplication app = new DummyApplication()
 		{
 			@Override
 			protected void init() 
@@ -59,7 +61,8 @@
 			}
 		};
 
-		this.application.getMarkupSettings().setMarkupParserFactory(new MarkupParserFactory()
+		tester = new WicketTester(app);
+		this.tester.getApplication().getMarkupSettings().setMarkupParserFactory(new MarkupParserFactory()
 		{
 			@Override
 			public MarkupParser newMarkupParser(MarkupResourceStream resource)

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/internal/HtmlHeaderContainerTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/internal/HtmlHeaderContainerTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/internal/HtmlHeaderContainerTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/internal/HtmlHeaderContainerTest.java Mon Nov  6 05:33:20 2006
@@ -19,6 +19,7 @@
 package wicket.markup.html.internal;
 
 import wicket.WicketTestCase;
+import wicket.util.tester.WicketTester;
 
 /**
  * Test for the {@link wicket.markup.html.internal.HeaderContainer}.
@@ -43,13 +44,13 @@
 	 */
 	public void testCleanUpOfAutoAddedComponents()
 	{
-		application.setHomePage(ComponentResolvingPage.class);
-		application.setupRequestAndResponse();
-		application.processRequestCycle();
+		tester = new WicketTester(ComponentResolvingPage.class);
+		tester.setupRequestAndResponse();
+		tester.processRequestCycle();
 
 		// onEndRequest() of auto added component was not called in
 		// MarkupContainer#internalEndRequest() using an iterator
-		ComponentResolvingPage page = (ComponentResolvingPage)application.getLastRenderedPage();
+		ComponentResolvingPage page = (ComponentResolvingPage)tester.getLastRenderedPage();
 		assertTrue("onEndRequest() should be called",
 				page.onEndRequestWasCalledOnAutoAddedComponent);
 	}

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkPageExpectedResult_1.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkPageExpectedResult_1.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkPageExpectedResult_1.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkPageExpectedResult_1.html Mon Nov  6 05:33:20 2006
@@ -3,33 +3,33 @@
 <title>Mock Page</title>
 </head>
 <body>
-<a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.link.Page1">Home</a>
+<a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.link.Page1">Home</a>
 <wicket:link>
-  <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.link.Page1">Home</a>
+  <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.link.Page1">Home</a>
 </wicket:link>
 <wicket:link autolink="false">
-  <a href="/WicketTester/Page1.html">Home</a>
+  <a href="/DummyApplication/Page1.html">Home</a>
 </wicket:link>
 <wicket:link autolink="true">
-  <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.link.Page1"><span wicket:id="myLabel">Home</span></a>
+  <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.link.Page1"><span wicket:id="myLabel">Home</span></a>
 </wicket:link>
 <wicket:link autolink="false">
-  <a href="/WicketTester/Page1.html">Home</a>
+  <a href="/DummyApplication/Page1.html">Home</a>
   <wicket:link autolink="true">
-    <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.link.Page1&amp;name=test&amp;id=123">Home</a>
+    <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.link.Page1&amp;name=test&amp;id=123">Home</a>
   </wicket:link>
 </wicket:link>
 <!-- valid till the end of the document or the next link tag -->
 <wicket:link autolink="false"/>
-<a href="/WicketTester/Page1.html">Home</a>
+<a href="/DummyApplication/Page1.html">Home</a>
 <wicket:link autolink="true"/>
-<a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.link.subdir.Page1">Home</a>
-<link href="/WicketTester/WicketTester/resources/wicket.markup.html.link.AutolinkPage_1/test_myStyle.css"/>
-<link href="/WicketTester/WicketTester/resources/wicket.markup.html.link.AutolinkPage_1/test2_myStyle.css"/>
-<link href="/WicketTester/WicketTester/resources/wicket.markup.html.link.AutolinkPage_1/test3_myStyle_de_DE.css"/>
-<link href="/WicketTester/WicketTester/resources/wicket.markup.html.link.AutolinkPage_1/../../html/link/test2_myStyle.css"/>
+<a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.link.subdir.Page1">Home</a>
+<link href="/DummyApplication/DummyApplication/resources/wicket.markup.html.link.AutolinkPage_1/test_myStyle.css"/>
+<link href="/DummyApplication/DummyApplication/resources/wicket.markup.html.link.AutolinkPage_1/test2_myStyle.css"/>
+<link href="/DummyApplication/DummyApplication/resources/wicket.markup.html.link.AutolinkPage_1/test3_myStyle_de_DE.css"/>
+<link href="/DummyApplication/DummyApplication/resources/wicket.markup.html.link.AutolinkPage_1/../../html/link/test2_myStyle.css"/>
 <a href="/root/test.html">Home</a>
-<a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.link.Page1">Home</a>
+<a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.link.Page1">Home</a>
   <a href="http://www.google.com">Google</a>
 </body>
 </html>

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkPageExpectedResult_2.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkPageExpectedResult_2.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkPageExpectedResult_2.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkPageExpectedResult_2.html Mon Nov  6 05:33:20 2006
@@ -3,30 +3,30 @@
 <title>Mock Page</title>
 </head>
 <body>
-<a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.link.Page1">Home</a>
+<a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.link.Page1">Home</a>
 
-  <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.link.Page1">Home</a>
+  <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.link.Page1">Home</a>
 
 
-  <a href="/WicketTester/Page1.html">Home</a>
+  <a href="/DummyApplication/Page1.html">Home</a>
 
 
-  <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.link.Page1"><span>Home</span></a>
+  <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.link.Page1"><span>Home</span></a>
 
 
-  <a href="/WicketTester/Page1.html">Home</a>
+  <a href="/DummyApplication/Page1.html">Home</a>
   
-    <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.link.Page1&amp;name=test&amp;id=123">Home</a>
+    <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.link.Page1&amp;name=test&amp;id=123">Home</a>
   
 
 <!-- valid till the end of the document or the next link tag -->
 
-<a href="/WicketTester/Page1.html">Home</a>
+<a href="/DummyApplication/Page1.html">Home</a>
 
-<a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.link.subdir.Page1">Home</a>
-<link href="/WicketTester/WicketTester/resources/wicket.markup.html.link.AutolinkPage_2/test_myStyle.css"/>
+<a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.link.subdir.Page1">Home</a>
+<link href="/DummyApplication/DummyApplication/resources/wicket.markup.html.link.AutolinkPage_2/test_myStyle.css"/>
 <a href="/root/test.html">Home</a>
-<a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.link.Page1">Home</a>
+<a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.link.Page1">Home</a>
   <a href="http://www.google.com">Google</a>
 </body>
 </html>

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkPageExpectedResult_3.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkPageExpectedResult_3.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkPageExpectedResult_3.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkPageExpectedResult_3.html Mon Nov  6 05:33:20 2006
@@ -1,7 +1,7 @@
 <html xmlns:wicket>
 <body>
 <wicket:link autolink="true">
-  <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.link.XmlPage">Home</a>
+  <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.link.XmlPage">Home</a>
 </wicket:link>
 </body>
 </html>

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkPageExpectedResult_4.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkPageExpectedResult_4.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkPageExpectedResult_4.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkPageExpectedResult_4.html Mon Nov  6 05:33:20 2006
@@ -8,7 +8,7 @@
   <!-- Not sure what it should do, but it is obviously valid => Do not change href at all -->
   <a href="">Link 1</a>
   <!-- Supported since 1.2 -->
-  <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=:wicket.markup.html.link.Page1#link1">Link 1</a>
+  <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.link.Page1#link1">Link 1</a>
   <!-- Supported since 2.0 -->
   <a href="Page.html?0=whatever">Link with parameter</a>
 </wicket:link>

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/AutolinkTest.java Mon Nov  6 05:33:20 2006
@@ -46,7 +46,7 @@
 	 */
 	public void testRenderHomePage_1() throws Exception
 	{
-		application.getMarkupSettings().setAutomaticLinking(true);
+		tester.getApplication().getMarkupSettings().setAutomaticLinking(true);
 		executeTest(AutolinkPage_1.class, "AutolinkPageExpectedResult_1.html");
 	}
 
@@ -55,8 +55,8 @@
 	 */
 	public void testRenderHomePage_2() throws Exception
 	{
-		application.getMarkupSettings().setAutomaticLinking(true);
-		application.getMarkupSettings().setStripWicketTags(true);
+		tester.getApplication().getMarkupSettings().setAutomaticLinking(true);
+		tester.getApplication().getMarkupSettings().setStripWicketTags(true);
 		executeTest(AutolinkPage_2.class, "AutolinkPageExpectedResult_2.html");
 	}
 
@@ -65,7 +65,7 @@
 	 */
 	public void testRenderHomePage_3() throws Exception
 	{
-		application.getMarkupSettings().setAutomaticLinking(true);
+		tester.getApplication().getMarkupSettings().setAutomaticLinking(true);
 		executeTest(AutolinkPage_3.class, "AutolinkPageExpectedResult_3.html");
 	}
 
@@ -74,7 +74,7 @@
 	 */
 	public void testRenderHomePage_4() throws Exception
 	{
-		application.getMarkupSettings().setAutomaticLinking(true);
+		tester.getApplication().getMarkupSettings().setAutomaticLinking(true);
 		executeTest(AutolinkPage_4.class, "AutolinkPageExpectedResult_4.html");
 	}
 }

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/BookmarkableHomePageLinksPage_result.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/BookmarkableHomePageLinksPage_result.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/BookmarkableHomePageLinksPage_result.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/BookmarkableHomePageLinksPage_result.html Mon Nov  6 05:33:20 2006
@@ -14,8 +14,8 @@
 -->
 <html xmlns:wicket>
 <body>
-  <a href="/WicketTester/WicketTester" wicket:id="defaulthompage"></a>
-  <a href="/WicketTester/WicketTester?param2=test&amp;param1=1" wicket:id="defaulthompagewithparams"></a>
-  <a href="/WicketTester/WicketTester?wicket:bookmarkablePage=testpagemap:wicket.markup.html.link.BookmarkableHomePageLinksPage" wicket:id="defaulthompagewithpagemap"></a>
+  <a href="/DummyApplication/DummyApplication" wicket:id="defaulthompage"></a>
+  <a href="/DummyApplication/DummyApplication?param2=test&amp;param1=1" wicket:id="defaulthompagewithparams"></a>
+  <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=testpagemap:wicket.resource.DummyPage" wicket:id="defaulthompagewithpagemap"></a>
 </body>
 </html>

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/ContextPathLinkTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/ContextPathLinkTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/ContextPathLinkTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/ContextPathLinkTest.java Mon Nov  6 05:33:20 2006
@@ -39,7 +39,6 @@
  */
 public class ContextPathLinkTest extends WicketTestCase
 {
-
 	/**
 	 * Construct.
 	 * 
@@ -63,7 +62,7 @@
 	 */
 	public void testEmptyContextPath() throws Exception
 	{
-		application.getApplicationSettings().setContextPath("");
+		tester.getApplication().getApplicationSettings().setContextPath("");
 		executeTest(ContextPathPage.class, "ContextPathPageEmptyContextResult.html");
 	}
 
@@ -72,8 +71,7 @@
 	 */
 	public void testNamedContextPath() throws Exception
 	{
-		application.getApplicationSettings().setContextPath("root");
+		tester.getApplication().getApplicationSettings().setContextPath("root");
 		executeTest(ContextPathPage.class, "ContextPathPageRootContextResult.html");
 	}
-
 }

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/ContextPathPageDefaultContextResult.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/ContextPathPageDefaultContextResult.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/ContextPathPageDefaultContextResult.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/ContextPathPageDefaultContextResult.html Mon Nov  6 05:33:20 2006
@@ -14,8 +14,8 @@
 -->
 <html>
 <body>
-  <a href="/WicketTester/WicketTester" wicket:id="bookmarkablelink"></a>
-  <a href="/WicketTester/WicketTester?wicket:interface=:0:resourcelink::IResourceListener" wicket:id="resourcelink"/>
-  <a href="/WicketTester/WicketTester?wicket:interface=:0:onclick::ILinkListener" wicket:id="onclick"/>
+  <a href="/DummyApplication/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.link.ContextPathPage" wicket:id="bookmarkablelink"></a>
+  <a href="/DummyApplication/DummyApplication?wicket:interface=:0:resourcelink::IResourceListener" wicket:id="resourcelink"/>
+  <a href="/DummyApplication/DummyApplication?wicket:interface=:0:onclick::ILinkListener" wicket:id="onclick"/>
 </body>
 </html>

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/ContextPathPageEmptyContextResult.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/ContextPathPageEmptyContextResult.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/ContextPathPageEmptyContextResult.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/ContextPathPageEmptyContextResult.html Mon Nov  6 05:33:20 2006
@@ -14,8 +14,8 @@
 -->
 <html>
 <body>
-  <a href="/WicketTester" wicket:id="bookmarkablelink"></a>
-  <a href="/WicketTester?wicket:interface=:0:resourcelink::IResourceListener" wicket:id="resourcelink"/>
-  <a href="/WicketTester?wicket:interface=:0:onclick::ILinkListener" wicket:id="onclick"/>
+  <a href="/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.link.ContextPathPage" wicket:id="bookmarkablelink"></a>
+  <a href="/DummyApplication?wicket:interface=:0:resourcelink::IResourceListener" wicket:id="resourcelink"/>
+  <a href="/DummyApplication?wicket:interface=:0:onclick::ILinkListener" wicket:id="onclick"/>
 </body>
 </html>

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/ContextPathPageRootContextResult.html
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/ContextPathPageRootContextResult.html?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/ContextPathPageRootContextResult.html (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/ContextPathPageRootContextResult.html Mon Nov  6 05:33:20 2006
@@ -14,8 +14,8 @@
 -->
 <html>
 <body>
-  <a href="/root/WicketTester" wicket:id="bookmarkablelink"></a>
-  <a href="/root/WicketTester?wicket:interface=:0:resourcelink::IResourceListener" wicket:id="resourcelink"/>
-  <a href="/root/WicketTester?wicket:interface=:0:onclick::ILinkListener" wicket:id="onclick"/>
+  <a href="/root/DummyApplication?wicket:bookmarkablePage=:wicket.markup.html.link.ContextPathPage" wicket:id="bookmarkablelink"></a>
+  <a href="/root/DummyApplication?wicket:interface=:0:resourcelink::IResourceListener" wicket:id="resourcelink"/>
+  <a href="/root/DummyApplication?wicket:interface=:0:onclick::ILinkListener" wicket:id="onclick"/>
 </body>
 </html>

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/HrefTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/HrefTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/PackageResourceTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/PackageResourceTest.java Mon Nov  6 05:33:20 2006
@@ -20,7 +20,7 @@
 import junit.framework.TestCase;
 import wicket.Application;
 import wicket.SharedResources;
-import wicket.protocol.http.MockWebApplication;
+import wicket.util.tester.WicketTester;
 
 /**
  * Tests for package resources.
@@ -29,8 +29,8 @@
  */
 public class PackageResourceTest extends TestCase
 {
-	/** mock application object */
-	public MockWebApplication application;
+	/** mock tester object */
+	public WicketTester tester;
 
 	/**
 	 * Construct.
@@ -51,6 +51,15 @@
 	}
 
 	/**
+	 * @see junit.framework.TestCase#setUp()
+	 */
+	@Override
+	protected void setUp() throws Exception
+	{
+		tester = new WicketTester();
+	}
+
+	/**
 	 * Tests binding a single absolute package resource.
 	 * 
 	 * @throws Exception
@@ -58,7 +67,7 @@
 	public void testBindAbsolutePackageResource() throws Exception
 	{
 		final SharedResources sharedResources = Application.get().getSharedResources();
-		PackageResource.bind(application, PackageResourceTest.class, "packaged1.txt");
+		PackageResource.bind(tester.getApplication(), PackageResourceTest.class, "packaged1.txt");
 		assertNotNull("resource packaged1.txt should be available as a packaged resource",
 				sharedResources.get(PackageResourceTest.class, "packaged1.txt", null, null, true));
 		assertNull("resource packaged2.txt should NOT be available as a packaged resource",
@@ -84,14 +93,5 @@
 		assertTrue(guard.accept(PackageResourceTest.class, ".Bar"));
 		assertTrue(guard.accept(PackageResourceTest.class, ".java"));
 		assertFalse(guard.accept(PackageResourceTest.class, "Bar.java"));
-	}
-
-	/**
-	 * @see junit.framework.TestCase#setUp()
-	 */
-	@Override
-	protected void setUp() throws Exception
-	{
-		application = new MockWebApplication(null);
 	}
 }

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/ScopedComponentResolverTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/ScopedComponentResolverTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/basic/SimplePageTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/basic/SimplePageTest.java Mon Nov  6 05:33:20 2006
@@ -28,7 +28,7 @@
 import wicket.util.value.IValueMap;
 
 /**
  * Simple application that demonstrates the mock http application code (and
  * checks that it is working)
  * 
  * @author Chris Turner
@@ -61,44 +61,44 @@
 	{
 		executeTest(SimplePage.class, "SimplePageExpectedResult.html");
 
-		Label label = (Label)application.getLastRenderedPage().get("myLabel");
+		Label label = (Label)tester.getLastRenderedPage().get("myLabel");
 		assertNotNull(label);
-		application.processRequestCycle(label);
-		String document = application.getServletResponse().getDocument();
+		tester.processRequestCycle(label);
+		String document = tester.getServletResponse().getDocument();
 		assertNotNull(document);
 		assertEquals("<span wicket:id=\"myLabel\">Test Label</span>", document);
 
-		Panel panel = (Panel)application.getLastRenderedPage().get("myPanel");
+		Panel panel = (Panel)tester.getLastRenderedPage().get("myPanel");
 		assertNotNull(panel);
-		application.processRequestCycle(panel);
-		document = application.getServletResponse().getDocument();
+		tester.processRequestCycle(panel);
+		document = tester.getServletResponse().getDocument();
 		assertNotNull(document);
 		assertEquals(
 				"<wicket:panel>Inside the panel<span wicket:id=\"label\">mein Label</span></wicket:panel>",
 				document);
 
-		label = (Label)application.getLastRenderedPage().get("myPanel:label");
+		label = (Label)tester.getLastRenderedPage().get("myPanel:label");
 		assertNotNull(label);
-		application.processRequestCycle(label);
-		document = application.getServletResponse().getDocument();
+		tester.processRequestCycle(label);
+		document = tester.getServletResponse().getDocument();
 		assertNotNull(document);
 		assertFalse("".equals(document));
 		assertEquals("<span wicket:id=\"label\">mein Label</span>", document);
 
-		Border border = (Border)application.getLastRenderedPage().get("myBorder");
+		Border border = (Border)tester.getLastRenderedPage().get("myBorder");
 		assertNotNull(border);
-		application.processRequestCycle(border);
-		document = application.getServletResponse().getDocument();
+		tester.processRequestCycle(border);
+		document = tester.getServletResponse().getDocument();
 		assertNotNull(document);
 		assertFalse("".equals(document));
 		assertEquals(
 				"<wicket:border>before body - <wicket:body>border</wicket:body> - after body</wicket:border>",
 				document);
 
-		border = (Border)application.getLastRenderedPage().get("myBorder2");
+		border = (Border)tester.getLastRenderedPage().get("myBorder2");
 		assertNotNull(border);
-		application.processRequestCycle(border);
-		document = application.getServletResponse().getDocument();
+		tester.processRequestCycle(border);
+		document = tester.getServletResponse().getDocument();
 		assertNotNull(document);
 		assertFalse("".equals(document));
 		assertEquals(
@@ -107,29 +107,29 @@
 
 		// do the same test twice. Igor reported a problem with that, so we have
 		// to test it.
-		border = (Border)application.getLastRenderedPage().get("myBorder2");
+		border = (Border)tester.getLastRenderedPage().get("myBorder2");
 		assertNotNull(border);
-		application.processRequestCycle(border);
-		document = application.getServletResponse().getDocument();
+		tester.processRequestCycle(border);
+		document = tester.getServletResponse().getDocument();
 		assertNotNull(document);
 		assertFalse("".equals(document));
 		assertEquals(
 				"<span testAttr=\"myValue\" wicket:id=\"myBorder2\"><wicket:border>before body - <wicket:body>border</wicket:body> - after body</wicket:border></span>",
 				document);
 
-		WebMarkupContainer container = (WebMarkupContainer)application.getLastRenderedPage().get(
+		WebMarkupContainer container = (WebMarkupContainer)tester.getLastRenderedPage().get(
 				"test");
 		assertNotNull(container);
-		application.processRequestCycle(container);
-		document = application.getServletResponse().getDocument();
+		tester.processRequestCycle(container);
+		document = tester.getServletResponse().getDocument();
 		assertNotNull(document);
 		assertFalse("".equals(document));
 		assertEquals("body<span wicket:id=\"myLabel2\">Test Label2</span>", document);
 
-		label = (Label)application.getLastRenderedPage().get("test:myLabel2");
+		label = (Label)tester.getLastRenderedPage().get("test:myLabel2");
 		assertNotNull(label);
-		application.processRequestCycle(label);
-		document = application.getServletResponse().getDocument();
+		tester.processRequestCycle(label);
+		document = tester.getServletResponse().getDocument();
 		assertNotNull(document);
 		assertFalse("".equals(document));
 		assertEquals("<span wicket:id=\"myLabel2\">Test Label2</span>", document);
@@ -145,15 +145,15 @@
 
 		Label label = (Label)page.get("myLabel");
 		assertNotNull(label);
-		application.processRequestCycle(label);
-		String document = application.getServletResponse().getDocument();
+		tester.processRequestCycle(label);
+		String document = tester.getServletResponse().getDocument();
 		assertNotNull(document);
 		assertEquals("<span wicket:id=\"myLabel\">Test Label</span>", document);
 
 		Panel panel = (Panel)page.get("myPanel");
 		assertNotNull(panel);
-		application.processRequestCycle(panel);
-		document = application.getServletResponse().getDocument();
+		tester.processRequestCycle(panel);
+		document = tester.getServletResponse().getDocument();
 		assertNotNull(document);
 		assertEquals(
 				"<wicket:panel>Inside the panel<span wicket:id=\"label\">mein Label</span></wicket:panel>",
@@ -161,16 +161,16 @@
 
 		label = (Label)page.get("myPanel:label");
 		assertNotNull(label);
-		application.processRequestCycle(label);
-		document = application.getServletResponse().getDocument();
+		tester.processRequestCycle(label);
+		document = tester.getServletResponse().getDocument();
 		assertNotNull(document);
 		assertFalse("".equals(document));
 		assertEquals("<span wicket:id=\"label\">mein Label</span>", document);
 
 		Border border = (Border)page.get("myBorder");
 		assertNotNull(border);
-		application.processRequestCycle(border);
-		document = application.getServletResponse().getDocument();
+		tester.processRequestCycle(border);
+		document = tester.getServletResponse().getDocument();
 		assertNotNull(document);
 		assertFalse("".equals(document));
 		assertEquals(
@@ -179,8 +179,8 @@
 
 		border = (Border)page.get("myBorder2");
 		assertNotNull(border);
-		application.processRequestCycle(border);
-		document = application.getServletResponse().getDocument();
+		tester.processRequestCycle(border);
+		document = tester.getServletResponse().getDocument();
 		assertNotNull(document);
 		assertFalse("".equals(document));
 		assertEquals(
@@ -191,8 +191,8 @@
 		// to test it.
 		border = (Border)page.get("myBorder2");
 		assertNotNull(border);
-		application.processRequestCycle(border);
-		document = application.getServletResponse().getDocument();
+		tester.processRequestCycle(border);
+		document = tester.getServletResponse().getDocument();
 		assertNotNull(document);
 		assertFalse("".equals(document));
 		assertEquals(
@@ -201,16 +201,16 @@
 
 		WebMarkupContainer container = (WebMarkupContainer)page.get("test");
 		assertNotNull(container);
-		application.processRequestCycle(container);
-		document = application.getServletResponse().getDocument();
+		tester.processRequestCycle(container);
+		document = tester.getServletResponse().getDocument();
 		assertNotNull(document);
 		assertFalse("".equals(document));
 		assertEquals("body<span wicket:id=\"myLabel2\">Test Label2</span>", document);
 
 		label = (Label)page.get("test:myLabel2");
 		assertNotNull(label);
-		application.processRequestCycle(label);
-		document = application.getServletResponse().getDocument();
+		tester.processRequestCycle(label);
+		document = tester.getServletResponse().getDocument();
 		assertNotNull(document);
 		assertFalse("".equals(document));
 		assertEquals("<span wicket:id=\"myLabel2\">Test Label2</span>", document);
@@ -380,11 +380,11 @@
 	{
 		executeTest(SimplePage_10.class, "SimplePageExpectedResult_10.html");
 
-		Panel panel = (Panel)application.getLastRenderedPage().get("myPanel");
+		Panel panel = (Panel)tester.getLastRenderedPage().get("myPanel");
 		assertNotNull(panel);
 		panel.setVisible(true);
-		application.processRequestCycle(panel);
-		String document = application.getServletResponse().getDocument();
+		tester.processRequestCycle(panel);
+		String document = tester.getServletResponse().getDocument();
 		assertNotNull(document);
 		assertEquals(
 				"<wicket:panel>Inside the panel<span wicket:id=\"label\">mein Label</span></wicket:panel>",
@@ -28,7 +28,7 @@
 
 /**
- * Simple application that demonstrates the mock http application code (and
+ * Simple tester that demonstrates the mock http tester code (and
  * checks that it is working)
  * 

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/basic/SimpleResponsePageClassTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/basic/SimpleResponsePageClassTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/persistence/CookieValuePersisterTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/persistence/CookieValuePersisterTest.java Mon Nov  6 05:33:20 2006
@@ -29,14 +29,14 @@
 import wicket.markup.html.form.persistence.CookieValuePersisterTestPage.TestForm;
 import wicket.protocol.http.MockHttpServletRequest;
 import wicket.protocol.http.MockHttpServletResponse;
-import wicket.protocol.http.MockWebApplication;
 import wicket.protocol.http.WebRequest;
 import wicket.protocol.http.WebRequestCycle;
 import wicket.protocol.http.WebResponse;
+import wicket.util.tester.WicketTester;
 
 /**
  * How to test CookieValuePersister. Problem: CookieValuePersister relies on
  * RequestCycle.get().getApplication() to access application settings.
  * RequestCycle.get() however is valid only during the render process. It get's
  * automatically attached and detached. Thus RequestCycle.get() will be NULL
  * before and after render. Thus CookieValuePersister can not be tested outside
@@ -57,16 +57,15 @@
  */
 public class CookieValuePersisterTest extends TestCase
 {
-	private MockWebApplication application;
+	private WicketTester tester;
 
 	@Override
 	protected void setUp() throws Exception
 	{
 		super.setUp();
-		application = new MockWebApplication(null);
-		application.setHomePage(CookieValuePersisterTestPage.class);
-		application.setupRequestAndResponse();
-		application.processRequestCycle();
+		tester = new WicketTester(CookieValuePersisterTestPage.class);
+		tester.setupRequestAndResponse();
+		tester.processRequestCycle();
 	}
 
 	/**
@@ -78,7 +77,7 @@
 	{
 		// How does the test work: Make sure you have a page, form and form
 		// component properly set up (getRelativePath() etc.). See setUp().
-		final Page page = application.getLastRenderedPage();
+		final Page page = tester.getLastRenderedPage();
 
 		// Get the form and form component created
 		final TestForm form = (TestForm)page.get("form");
@@ -88,7 +87,7 @@
 		// The RequestCycle's constructor will attach the new cycle to
 		// the threadLocal retrieved by RequestCycle.get().
 		// Attached to this cycle must be a valid request and response
-		final WebRequestCycle cycle = application.createRequestCycle();
+		final WebRequestCycle cycle = tester.createRequestCycle();
 
 		// Just after init, the requests and responses cookie lists must be
 		// empty
@@ -29,14 +29,14 @@
 /**
  * How to test CookieValuePersister. Problem: CookieValuePersister relies on
- * RequestCycle.get().getApplication() to access application settings.
+ * RequestCycle.get().getApplication() to access tester settings.
  * RequestCycle.get() however is valid only during the render process. It get's
  * automatically attached and detached. Thus RequestCycle.get() will be NULL

Modified: incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/upload/FileUploadFieldTest.java
URL: http://svn.apache.org/viewvc/incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/form/upload/FileUploadFieldTest.java?view=diff&rev=471726&r1=471725&r2=471726
==============================================================================
--- incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/HrefTest.java (original)
+++ incubator/wicket/trunk/wicket/src/test/java/wicket/markup/html/link/HrefTest.java Mon Nov  6 05:33:20 2006
@@ -21,7 +21,7 @@
 import wicket.WicketTestCase;
 
 /**
  * Simple application that demonstrates the mock http application code (and
  * checks that it is working)
  * 
  * @author Chris Turner
@@ -48,7 +48,7 @@
 	 */
 	public void testRenderHomePage_1() throws Exception
 	{
-		application.getMarkupSettings().setStripWicketTags(false);
+		tester.getApplication().getMarkupSettings().setStripWicketTags(false);
 		executeTest(Href_1.class, "HrefExpectedResult_1.html");
 	}
 
@@ -59,7 +59,7 @@
 	 */
 	public void testRenderHomePage_2() throws Exception
 	{
-		application.getMarkupSettings().setStripWicketTags(true);
+		tester.getApplication().getMarkupSettings().setStripWicketTags(true);
 		executeTest(Href_1.class, "HrefExpectedResult_1-1.html");
 	}
 
@@ -70,7 +70,7 @@
 	 */
 	public void testRenderHomePage_2a() throws Exception
 	{
-		application.getMarkupSettings().setStripWicketTags(true);
+		tester.getApplication().getMarkupSettings().setStripWicketTags(true);
 		executeTest(Href_2.class, "HrefExpectedResult_2.html");
 	}
@@ -21,7 +21,7 @@
 
 /**
- * Simple application that demonstrates the mock http application code (and
+ * Simple tester that demonstrates the mock http tester code (and
  * checks that it is working)
  * 